# Custom Vue module

This sub-directory capture the client side components that you want to expose inside your trame application.

## Build

```bash
npm i
npm run build
```

## Develop component live

```bash
npm run serve:CustomWidget
```
